# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`apptainer`](#apptainer): Manage Apptainer

#### Private Classes

* `apptainer::config`: Private class
* `apptainer::install::os`: Private class
* `apptainer::install::package`: Private class
* `apptainer::install::source`: Private class
* `apptainer::singularity`: Private class

### Defined types

* [`apptainer::plugin`](#apptainer--plugin): Manage Apptainer plugin

## Classes

### <a name="apptainer"></a>`apptainer`

Manage Apptainer

#### Examples

##### 

```puppet
include ::apptainer
```

#### Parameters

The following parameters are available in the `apptainer` class:

* [`install_method`](#-apptainer--install_method)
* [`install_setuid`](#-apptainer--install_setuid)
* [`version`](#-apptainer--version)
* [`manage_repo`](#-apptainer--manage_repo)
* [`remove_singularity`](#-apptainer--remove_singularity)
* [`package_name`](#-apptainer--package_name)
* [`source_dependencies`](#-apptainer--source_dependencies)
* [`manage_go`](#-apptainer--manage_go)
* [`rebuild_on_go`](#-apptainer--rebuild_on_go)
* [`source_base_dir`](#-apptainer--source_base_dir)
* [`source_mconfig_path`](#-apptainer--source_mconfig_path)
* [`build_flags`](#-apptainer--build_flags)
* [`build_env`](#-apptainer--build_env)
* [`prefix`](#-apptainer--prefix)
* [`localstatedir`](#-apptainer--localstatedir)
* [`sysconfdir`](#-apptainer--sysconfdir)
* [`source_exec_path`](#-apptainer--source_exec_path)
* [`plugins`](#-apptainer--plugins)
* [`config_path`](#-apptainer--config_path)
* [`config_template`](#-apptainer--config_template)
* [`allow_setuid`](#-apptainer--allow_setuid)
* [`max_loop_devices`](#-apptainer--max_loop_devices)
* [`allow_pid_ns`](#-apptainer--allow_pid_ns)
* [`config_passwd`](#-apptainer--config_passwd)
* [`config_group`](#-apptainer--config_group)
* [`config_resolv_conf`](#-apptainer--config_resolv_conf)
* [`mount_proc`](#-apptainer--mount_proc)
* [`mount_sys`](#-apptainer--mount_sys)
* [`mount_dev`](#-apptainer--mount_dev)
* [`mount_devpts`](#-apptainer--mount_devpts)
* [`mount_home`](#-apptainer--mount_home)
* [`mount_tmp`](#-apptainer--mount_tmp)
* [`mount_hostfs`](#-apptainer--mount_hostfs)
* [`bind_paths`](#-apptainer--bind_paths)
* [`user_bind_control`](#-apptainer--user_bind_control)
* [`enable_fusemount`](#-apptainer--enable_fusemount)
* [`enable_overlay`](#-apptainer--enable_overlay)
* [`enable_underlay`](#-apptainer--enable_underlay)
* [`mount_slave`](#-apptainer--mount_slave)
* [`sessiondir_max_size`](#-apptainer--sessiondir_max_size)
* [`limit_container_owners`](#-apptainer--limit_container_owners)
* [`limit_container_groups`](#-apptainer--limit_container_groups)
* [`limit_container_paths`](#-apptainer--limit_container_paths)
* [`allow_containers`](#-apptainer--allow_containers)
* [`allow_setuid_mount_encrypted`](#-apptainer--allow_setuid_mount_encrypted)
* [`allow_setuid_mount_squashfs`](#-apptainer--allow_setuid_mount_squashfs)
* [`allow_setuid_mount_extfs`](#-apptainer--allow_setuid_mount_extfs)
* [`allow_net_users`](#-apptainer--allow_net_users)
* [`allow_net_groups`](#-apptainer--allow_net_groups)
* [`allow_net_networks`](#-apptainer--allow_net_networks)
* [`always_use_nv`](#-apptainer--always_use_nv)
* [`use_nvidia_container_cli`](#-apptainer--use_nvidia_container_cli)
* [`always_use_rocm`](#-apptainer--always_use_rocm)
* [`root_default_capabilities`](#-apptainer--root_default_capabilities)
* [`memory_fs_type`](#-apptainer--memory_fs_type)
* [`cni_configuration_path`](#-apptainer--cni_configuration_path)
* [`cni_plugin_path`](#-apptainer--cni_plugin_path)
* [`binary_path`](#-apptainer--binary_path)
* [`mksquashfs_procs`](#-apptainer--mksquashfs_procs)
* [`mksquashfs_mem`](#-apptainer--mksquashfs_mem)
* [`shared_loop_devices`](#-apptainer--shared_loop_devices)
* [`image_driver`](#-apptainer--image_driver)
* [`download_concurrency`](#-apptainer--download_concurrency)
* [`download_part_size`](#-apptainer--download_part_size)
* [`download_buffer_size`](#-apptainer--download_buffer_size)
* [`systemd_cgroups`](#-apptainer--systemd_cgroups)
* [`apptheus_socket_path`](#-apptainer--apptheus_socket_path)
* [`allow_monitoring`](#-apptainer--allow_monitoring)
* [`namespace_users`](#-apptainer--namespace_users)
* [`namespace_begin_id`](#-apptainer--namespace_begin_id)
* [`namespace_id_range`](#-apptainer--namespace_id_range)
* [`subid_template`](#-apptainer--subid_template)

##### <a name="-apptainer--install_method"></a>`install_method`

Data type: `Enum['package','source','os']`

Sets how Apptainer will be installed,
`package` will install the upstream package
`source` from source
`os` will install from standard OS repositories for example from EPEL on RedHat family.

Default value: `'package'`

##### <a name="-apptainer--install_setuid"></a>`install_setuid`

Data type: `Boolean`

Whether to install the setuid portion of apptainer

Default value: `false`

##### <a name="-apptainer--version"></a>`version`

Data type: `String`

Version of Apptainer to install

Default value: `'1.3.3'`

##### <a name="-apptainer--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Enable repositories for apptainer packages, e.g. EPEL on RedHat

Default value: `true`

##### <a name="-apptainer--remove_singularity"></a>`remove_singularity`

Data type: `Boolean`

Set whether to remove Singularity before installing Apptainer

Default value: `false`

##### <a name="-apptainer--package_name"></a>`package_name`

Data type: `String`

Apptainer package name
Only used when install_method=package

Default value: `'apptainer'`

##### <a name="-apptainer--source_dependencies"></a>`source_dependencies`

Data type: `Array`

Packages needed to build from source
Only used when install_method=source

Default value: `[]`

##### <a name="-apptainer--manage_go"></a>`manage_go`

Data type: `Boolean`

Sets if golang module should be included
Only used when install_method=source

Default value: `true`

##### <a name="-apptainer--rebuild_on_go"></a>`rebuild_on_go`

Data type: `Boolean`

Sets if Apptainer should be rebuilt on updates to Go via golang module
Only used when install_method=source and manage_go=true

Default value: `true`

##### <a name="-apptainer--source_base_dir"></a>`source_base_dir`

Data type: `Stdlib::Absolutepath`

Base directory of where Apptainer source will be extracted
Only used when install_method=source

Default value: `'/opt'`

##### <a name="-apptainer--source_mconfig_path"></a>`source_mconfig_path`

Data type: `Stdlib::Absolutepath`

Path to source install mconfig script

Default value: `'/usr/local/sbin/apptainer-mconfig.sh'`

##### <a name="-apptainer--build_flags"></a>`build_flags`

Data type: `Hash`

Build flags to pass to mconfig when building Apptainer
Only used when install_method=source

Default value: `{}`

##### <a name="-apptainer--build_env"></a>`build_env`

Data type: `Hash`

Environment variables to use when building from source
Only used when install_method=source

Default value: `{}`

##### <a name="-apptainer--prefix"></a>`prefix`

Data type: `Stdlib::Absolutepath`

The --prefix value when building from source
Only used when install_method=source

Default value: `'/usr'`

##### <a name="-apptainer--localstatedir"></a>`localstatedir`

Data type: `Stdlib::Absolutepath`

The --localstatedir value when building from source
Only used when install_method=source

Default value: `'/var'`

##### <a name="-apptainer--sysconfdir"></a>`sysconfdir`

Data type: `Stdlib::Absolutepath`

The --sysconfdir value when building from source
Only used when install_method=source

Default value: `'/etc'`

##### <a name="-apptainer--source_exec_path"></a>`source_exec_path`

Data type: `String`

Set PATH when building from source
Only used when install_method=source

Default value: `'/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin'`

##### <a name="-apptainer--plugins"></a>`plugins`

Data type: `Hash`

Hash to define apptainer::plugin resources

Default value: `{}`

##### <a name="-apptainer--config_path"></a>`config_path`

Data type: `Stdlib::Absolutepath`

Path to apptainer.conf

Default value: `'/etc/apptainer/apptainer.conf'`

##### <a name="-apptainer--config_template"></a>`config_template`

Data type: `String`

Template used for apptainer.conf

Default value: `'apptainer/apptainer.conf.erb'`

##### <a name="-apptainer--allow_setuid"></a>`allow_setuid`

Data type: `Enum['yes','no']`

See apptainer.conf: `allow setuid`

Default value: `'yes'`

##### <a name="-apptainer--max_loop_devices"></a>`max_loop_devices`

Data type: `Integer`

See apptainer.conf: `max loop devices`

Default value: `256`

##### <a name="-apptainer--allow_pid_ns"></a>`allow_pid_ns`

Data type: `Enum['yes','no']`

See apptainer.conf: `allow pid ns`

Default value: `'yes'`

##### <a name="-apptainer--config_passwd"></a>`config_passwd`

Data type: `Enum['yes','no']`

See apptainer.conf: `config passwd`

Default value: `'yes'`

##### <a name="-apptainer--config_group"></a>`config_group`

Data type: `Enum['yes','no']`

See apptainer.conf: `config group`

Default value: `'yes'`

##### <a name="-apptainer--config_resolv_conf"></a>`config_resolv_conf`

Data type: `Enum['yes','no']`

See apptainer.conf: `config resolv conf`

Default value: `'yes'`

##### <a name="-apptainer--mount_proc"></a>`mount_proc`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount proc`

Default value: `'yes'`

##### <a name="-apptainer--mount_sys"></a>`mount_sys`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount sys`

Default value: `'yes'`

##### <a name="-apptainer--mount_dev"></a>`mount_dev`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount dev`

Default value: `'yes'`

##### <a name="-apptainer--mount_devpts"></a>`mount_devpts`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount devpts`

Default value: `'yes'`

##### <a name="-apptainer--mount_home"></a>`mount_home`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount home`

Default value: `'yes'`

##### <a name="-apptainer--mount_tmp"></a>`mount_tmp`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount tmp`

Default value: `'yes'`

##### <a name="-apptainer--mount_hostfs"></a>`mount_hostfs`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount hostfs`

Default value: `'no'`

##### <a name="-apptainer--bind_paths"></a>`bind_paths`

Data type: `Array[Stdlib::Absolutepath]`

See apptainer.conf: `bind paths`

Default value: `['/etc/localtime', '/etc/hosts']`

##### <a name="-apptainer--user_bind_control"></a>`user_bind_control`

Data type: `Enum['yes','no']`

See apptainer.conf: `user bind control`

Default value: `'yes'`

##### <a name="-apptainer--enable_fusemount"></a>`enable_fusemount`

Data type: `Enum['yes','no']`

See apptainer.conf: `enable fusemount`

Default value: `'yes'`

##### <a name="-apptainer--enable_overlay"></a>`enable_overlay`

Data type: `Enum['yes','no','try','driver']`

See apptainer.conf: `enable overlay`

Default value: `'yes'`

##### <a name="-apptainer--enable_underlay"></a>`enable_underlay`

Data type: `Enum['yes','no','preferred']`

See apptainer.conf: `enable underlay`

Default value: `'yes'`

##### <a name="-apptainer--mount_slave"></a>`mount_slave`

Data type: `Enum['yes','no']`

See apptainer.conf: `mount slave`

Default value: `'yes'`

##### <a name="-apptainer--sessiondir_max_size"></a>`sessiondir_max_size`

Data type: `Integer`

See apptainer.conf: `sessiondir max size`

Default value: `64`

##### <a name="-apptainer--limit_container_owners"></a>`limit_container_owners`

Data type: `Optional[Array]`

See apptainer.conf: `limit container owners`

Default value: `undef`

##### <a name="-apptainer--limit_container_groups"></a>`limit_container_groups`

Data type: `Optional[Array]`

See apptainer.conf: `limit container groups`

Default value: `undef`

##### <a name="-apptainer--limit_container_paths"></a>`limit_container_paths`

Data type: `Optional[Array]`

See apptainer.conf: `limit container paths`

Default value: `undef`

##### <a name="-apptainer--allow_containers"></a>`allow_containers`

Data type: `Hash[String,Enum['yes','no']]`

See apptainer.conf: `allow containers`

Default value:

```puppet
{
    'sif' => 'yes',
    'encrypted' => 'yes',
    'squashfs' => 'yes',
    'extfs' => 'yes',
    'dir' => 'yes',
  }
```

##### <a name="-apptainer--allow_setuid_mount_encrypted"></a>`allow_setuid_mount_encrypted`

Data type: `Optional[Enum['yes','no']]`

See apptainer.conf `allow setuid-mount encrypted`

Default value: `undef`

##### <a name="-apptainer--allow_setuid_mount_squashfs"></a>`allow_setuid_mount_squashfs`

Data type: `Optional[Enum['yes','no','iflimited']]`

See apptainer.conf `allow setuid-mount squashfs`

Default value: `undef`

##### <a name="-apptainer--allow_setuid_mount_extfs"></a>`allow_setuid_mount_extfs`

Data type: `Optional[Enum['yes','no']]`

See apptainer.conf `allow setuid-mount extfs`

Default value: `undef`

##### <a name="-apptainer--allow_net_users"></a>`allow_net_users`

Data type: `Array`

See apptainer.conf: `allow net users`

Default value: `[]`

##### <a name="-apptainer--allow_net_groups"></a>`allow_net_groups`

Data type: `Array`

See apptainer.conf: `allow net groups`

Default value: `[]`

##### <a name="-apptainer--allow_net_networks"></a>`allow_net_networks`

Data type: `Array`

See apptainer.conf: `allow net networks`

Default value: `[]`

##### <a name="-apptainer--always_use_nv"></a>`always_use_nv`

Data type: `Enum['yes','no']`

See apptainer.conf: `always use nv`

Default value: `'no'`

##### <a name="-apptainer--use_nvidia_container_cli"></a>`use_nvidia_container_cli`

Data type: `Enum['yes','no']`

See apptainer.conf: `use nvidia-container-cli`

Default value: `'no'`

##### <a name="-apptainer--always_use_rocm"></a>`always_use_rocm`

Data type: `Enum['yes','no']`

See apptainer.conf: `always use rocm`

Default value: `'no'`

##### <a name="-apptainer--root_default_capabilities"></a>`root_default_capabilities`

Data type: `Enum['full','file','default','no']`

See apptainer.conf: `root default capabilities`

Default value: `'full'`

##### <a name="-apptainer--memory_fs_type"></a>`memory_fs_type`

Data type: `Enum['tmpfs','ramfs']`

See apptainer.conf: `memory fs type`

Default value: `'tmpfs'`

##### <a name="-apptainer--cni_configuration_path"></a>`cni_configuration_path`

Data type: `Optional[Stdlib::Absolutepath]`

See apptainer.conf: `cni configuration path`

Default value: `undef`

##### <a name="-apptainer--cni_plugin_path"></a>`cni_plugin_path`

Data type: `Optional[Stdlib::Absolutepath]`

See apptainer.conf: `cni plugin path`

Default value: `undef`

##### <a name="-apptainer--binary_path"></a>`binary_path`

Data type: `Optional[String[1]]`

See apptainer.conf: `binary path`

Default value: `undef`

##### <a name="-apptainer--mksquashfs_procs"></a>`mksquashfs_procs`

Data type: `Integer[0,default]`

See apptainer.conf: `mksquashfs procs`

Default value: `0`

##### <a name="-apptainer--mksquashfs_mem"></a>`mksquashfs_mem`

Data type: `Optional[String[1]]`

See apptainer.conf: `mksquashfs mem`

Default value: `undef`

##### <a name="-apptainer--shared_loop_devices"></a>`shared_loop_devices`

Data type: `Enum['yes','no']`

See apptainer.conf: `shared loop devices`

Default value: `'no'`

##### <a name="-apptainer--image_driver"></a>`image_driver`

Data type: `Optional[String]`

See apptainer.conf: `image driver`

Default value: `undef`

##### <a name="-apptainer--download_concurrency"></a>`download_concurrency`

Data type: `Integer[0,default]`

See apptainer.conf: `download concurrency`

Default value: `3`

##### <a name="-apptainer--download_part_size"></a>`download_part_size`

Data type: `Integer[0,default]`

See apptainer.conf: `download part size`

Default value: `5242880`

##### <a name="-apptainer--download_buffer_size"></a>`download_buffer_size`

Data type: `Integer[0,default]`

See apptainer.conf: `download buffer size`

Default value: `32768`

##### <a name="-apptainer--systemd_cgroups"></a>`systemd_cgroups`

Data type: `Enum['yes','no']`

See apptainer.conf: `systemd cgroups`

Default value: `'yes'`

##### <a name="-apptainer--apptheus_socket_path"></a>`apptheus_socket_path`

Data type: `Stdlib::Absolutepath`

See apptainer.conf `apptheus socket path`

Default value: `'/run/apptheus/gateway.sock'`

##### <a name="-apptainer--allow_monitoring"></a>`allow_monitoring`

Data type: `Enum['yes','no']`

See apptainer.conf `allow monitoring`

Default value: `'no'`

##### <a name="-apptainer--namespace_users"></a>`namespace_users`

Data type: `Array`

List of uses to add to /etc/subuid and /etc/subgid to support user namespaces

Default value: `[]`

##### <a name="-apptainer--namespace_begin_id"></a>`namespace_begin_id`

Data type: `Integer`

The beginning ID for /etc/subuid and /etc/subgid. The value is incremented
For each user by start + namespace_id_range + 1

Default value: `65537`

##### <a name="-apptainer--namespace_id_range"></a>`namespace_id_range`

Data type: `Integer`

The range of UIDs/GIDs usable by a user in namespaces

Default value: `65536`

##### <a name="-apptainer--subid_template"></a>`subid_template`

Data type: `String`

The template to use for /etc/subuid and /etc/subgid

Default value: `'apptainer/subid.erb'`

## Defined types

### <a name="apptainer--plugin"></a>`apptainer::plugin`

Manage Apptainer plugin

#### Examples

##### install log plugin

```puppet

apptainer::plugin { 'github.com/apptainer/apptainer/log-plugin':
  source_dir => 'examples/plugins/log-plugin',
}
```

#### Parameters

The following parameters are available in the `apptainer::plugin` defined type:

* [`source_dir`](#-apptainer--plugin--source_dir)
* [`ensure`](#-apptainer--plugin--ensure)
* [`sif_name`](#-apptainer--plugin--sif_name)

##### <a name="-apptainer--plugin--source_dir"></a>`source_dir`

Data type: `Optional[String]`

The plugin source directory
This path must be relative to Apptainer source directory `$apptainer::install::source::source_dir`

Default value: `undef`

##### <a name="-apptainer--plugin--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Whether to install (present) or uninstall (absent) the plugin

Default value: `'present'`

##### <a name="-apptainer--plugin--sif_name"></a>`sif_name`

Data type: `Optional[String]`

The name of the SIF image to use for install after the plugin is compiled.
The default is to use part after last `/` in the plugin name so
plugin `examples/plugins/log-plugin` will have SIF name of `log-plugin.sif`.

Default value: `undef`

